/* Creating SalesOrder Table */

CREATE TABLE salesorder (
    SalesOrderID            INTEGER         PRIMARY KEY AUTOINCREMENT
                                            NOT NULL
                                            UNIQUE,
    PurchaseOrderNumber     VARCHAR(45),
    OrderDate               DATETIME        DEFAULT NULL,
    CurrencyType            VARCHAR(45),
    CustomerOrderNumber     VARCHAR(45),
    AmazonSiteNumber        VARCHAR(45),
    RequestedShippingDate   DATETIME        DEFAULT NULL,
    RequestedDeliveryDate   DATETIME        DEFAULT NULL,
    OrderStatusMessage      VARCHAR(264),
    AmazonLocationName      VARCHAR(60),
    AmazonLocationCode      VARCHAR(80),
    AmazonWarehouseCode     VARCHAR(60),
    ShippingName            VARCHAR(60),
    ShippingStreet          VARCHAR(55),
    ShippingCity            VARCHAR(45),
    ShippingState           VARCHAR(45),
    ShippingZip             VARCHAR(45),
    ShippingCountry         VARCHAR(45),
    ShippingMethod          VARCHAR(80),
    ShippingAddressType     VARCHAR(45),
    CustomerName            VARCHAR(60),
    BillingStreet           VARCHAR(55),
    BillingCity             VARCHAR(45),
    BillingState            VARCHAR(45),
    BillingZip              VARCHAR(45),
    BillingCountry          VARCHAR(45),
    CustomerPhone           VARCHAR(80),
    CustomerEmail           VARCHAR(80),
    NumberofLineItems       INTEGER,
    TotalNumberofUnits      INTEGER,
    GiftMessage             VARCHAR(45),
    TotalPrice              REAL            DEFAULT NULL
);

/* Creating SalesOrderLineItems Table*/

CREATE TABLE salesorderlineitems (
    LineItemsID             INTEGER         PRIMARY KEY AUTOINCREMENT
                                            NOT NULL
                                            UNIQUE,
    SalesOrderID            INTEGER,
    LineNumber              INTEGER,
    QuantityOrdered         INTEGER,
    UnitPrice               REAL            DEFAULT NULL,
    ProductID               VARCHAR(48),
    ProductDescription      VARCHAR(45)
);

/* Creating Invoice Table */

CREATE TABLE invoice (
    InvoiceID               INTEGER         PRIMARY KEY AUTOINCREMENT
                                            NOT NULL
                                            UNIQUE,
    InvoiceDate             DATETIME        DEFAULT NULL,
    InvoiceNumber           VARCHAR(45),
    CurrencyType            VARCHAR(45),
    RemittingName           VARCHAR(60),
    VendorPayeeCode         VARCHAR(80),
    RemittingStreet         VARCHAR(55),
    RemittingCity           VARCHAR(45),
    RemittingState          VARCHAR(45),
    RemittingZip            VARCHAR(45),
    RemittingCountry        VARCHAR(45),
    AmazonWarehouseCode     VARCHAR(60),
    TermsDueDate            DATETIME,
    TermsNetDays            INTEGER,
    TermsDescription        VARCHAR(45),
    InvoiceTotal            REAL            DEFAULT NULL,
    SACInfo                 VARCHAR(45),
    SACAmount               REAL            DEFAULT NULL
);

/* Creating InvoiceLineItems Table */

CREATE TABLE invoicelineitems (
    InvoiceLineItemsID      INTEGER         PRIMARY KEY AUTOINCREMENT
                                            NOT NULL
                                            UNIQUE,
    InvoiceID               INTEGER         DEFAULT NULL,
    LineNumber              INTEGER,
    QuantityInvoiced        INTEGER,
    ProductID               VARCHAR(45),
    UnitPrice               REAL            DEFAULT NULL,
    PurchaseOrderNumber     VARCHAR(48),
    VendorOrderNumber       VARCHAR(48),
    CustomerOrderNumber     VARCHAR(48)
);

/* Creating Items Table */
CREATE TABLE items (
    ItemsID                 INTEGER         PRIMARY KEY AUTOINCREMENT
                                            NOT NULL
                                            UNIQUE,
    InventoryFeedReference  VARCHAR (45)    DEFAULT NULL,
    Date                    DATETIME        DEFAULT NULL,
    ItemNumber              VARCHAR(48),
    AmazonWarehouseCode     VARCHAR(80),
    QuantityAvailable       INTEGER         DEFAULT NULL
);

/* Creating ASN Order Table */

CREATE TABLE ASNorder (
    ASNOrderID              INTEGER         PRIMARY KEY AUTOINCREMENT
                                            NOT NULL
                                            UNIQUE,
    HLID                    VARCHAR(45)     NOT NULL,
    HLParentID              VARCHAR(45)     NOT NULL,
    ShipmentId              VARCHAR(45),
    OrderDate               DATETIME        DEFAULT NULL,
    TransactionType         VARCHAR(45),
    StatusReasonCode        VARCHAR(45),
    PurchaseOrderNumber     VARCHAR(45),
    VendorOrderNumber       VARCHAR(48),
    AmazonWarehouseCode     VARCHAR(60)
);

/* Creating ASN Item Table */

CREATE TABLE ASNitem (
    ASNItemID               INTEGER         PRIMARY KEY AUTOINCREMENT
                                            NOT NULL
                                            UNIQUE,
    ASNOrderID              INTEGER         DEFAULT NULL,
    HLID                    VARCHAR(45)     NOT NULL,
    HLParentID              VARCHAR(45)     NOT NULL,
    LineNumber              INTEGER,
    ProductID               VARCHAR(45),
    QuantityShipped         INTEGER         DEFAULT NULL,
    QuantityOrdered         INTEGER         DEFAULT NULL,
    ItemStatusCode          VARCHAR(45),
    QuantityCancelled       INTEGER         DEFAULT NULL,
    UnitPrice               REAL            DEFAULT NULL,
    VendorPackageID         VARCHAR (48)    DEFAULT NULL
);

/* Creating ASN Package Table */

CREATE TABLE ASNpackage (
    ASNPackageID            INTEGER         PRIMARY KEY AUTOINCREMENT
                                            NOT NULL
                                            UNIQUE,
    ASNItemID               INTEGER         DEFAULT NULL,
    HLID                    VARCHAR(45)     NOT NULL,
    HLParentID              VARCHAR(45)     NOT NULL,
    WeightofPackage         REAL            DEFAULT NULL,
    ShippingMethod          VARCHAR(80),
    VendorPackageID         VARCHAR(48)     DEFAULT NULL,
    ManifestNumber          VARCHAR(45),
    TrackingID              VARCHAR(45),
    ShippingDate            DATETIME,
    ManifestShippingDate    DATETIME
);